A function that performs a utility computation of information about the differences of the classes.
lol.utils.deltas(centroids, priors, ...)[d, K] centroid matrix of the unique, ordered classes.
[K] vector containing prior probability for the unique, ordered classes.
optional args.
deltas [d, K] the K difference vectors.